@@ -23,7 +23,7 @@ from rasterio import _err, coords, enums
 
 __all__ = [
     'band', 'open', 'drivers', 'copy', 'pad']
-__version__ = "0.24.1"
+__version__ = "0.25.0"
 
 log = logging.getLogger('rasterio')
 class NullHandler(logging.Handler):
@@ -89,9 +89,13 @@ def open(
         raise TypeError("invalid mode: %r" % mode)
     if driver and not isinstance(driver, string_types):
         raise TypeError("invalid driver: %r" % driver)
+
     if transform:
         transform = guard_transform(transform)
-    
+    elif 'affine' in kwargs:
+        affine = kwargs.pop('affine')
+        transform = guard_transform(affine)
+
     if mode == 'r':
         from rasterio._io import RasterReader
         s = RasterReader(path)
