@@ -12,7 +12,7 @@ from cligj import (
     use_rs_opt, geojson_type_feature_opt, geojson_type_bbox_opt,
     files_inout_arg, format_opt, geojson_type_collection_opt)
 
-from .helpers import coords, resolve_inout, write_features
+from .helpers import coords, resolve_inout, write_features, to_lower
 from . import options
 import rasterio
 from rasterio.transform import Affine
@@ -49,6 +49,7 @@ all_touched_opt = click.option(
               help='Inverts the mask, so that areas covered by features are'
                    'masked out and areas not covered are retained.  Ignored '
                    'if using --crop')
+@options.creation_options
 @click.pass_context
 def mask(
         ctx,
@@ -58,7 +59,8 @@ def mask(
         driver,
         all_touched,
         crop,
-        invert):
+        invert,
+        creation_options):
 
     """Masks in raster using GeoJSON features (masks out all areas not covered
     by features), and optionally crops the output raster to the extent of the
@@ -102,9 +104,10 @@ def mask(
 
     with rasterio.drivers(CPL_DEBUG=verbosity > 2):
         try:
-            geojson = json.loads(click.open_file(geojson_mask).read())
+            with click.open_file(geojson_mask) as f:
+                geojson = json.loads(f.read())
         except ValueError:
-            raise click.BadParameter('GeoJSON could not be read from  '
+            raise click.BadParameter('GeoJSON could not be read from '
                                      '--geojson-mask or stdin',
                                      param_hint='--geojson-mask')
 
@@ -149,6 +152,7 @@ def mask(
                 invert=invert)
 
             meta = src.meta.copy()
+            meta.update(**creation_options)
             meta.update({
                 'driver': driver,
                 'height': mask.shape[0],
@@ -255,10 +259,14 @@ def shapes(
                 msk = None
 
                 # Adjust transforms.
-                if sampling == 1:
-                    transform = src.affine
-                else:
-                    transform = src.affine * Affine.scale(float(sampling))
+                transform = src.affine
+                if sampling > 1:
+                    # Decimation of the raster produces a georeferencing
+                    # shift that we correct with a translation.
+                    transform *= Affine.translation(
+                                    src.width%sampling, src.height%sampling)
+                    # And follow by scaling.
+                    transform *= Affine.scale(float(sampling))
 
                 # Most of the time, we'll use the valid data mask.
                 # We skip reading it if we're extracting every possible
@@ -359,8 +367,7 @@ def shapes(
 @format_opt
 @options.like_file_opt
 @options.bounds_opt
-@click.option('--dimensions', nargs=2, type=int, default=None,
-              help='Output dataset width, height in number of pixels.')
+@options.dimensions_opt
 @options.resolution_opt
 @click.option('--src-crs', '--src_crs', 'src_crs', default=None,
               help='Source coordinate reference system.  Limited to EPSG '
@@ -376,6 +383,7 @@ def shapes(
 @click.option('--property', type=str, default=None, help='Property in '
               'GeoJSON features to use for rasterized values.  Any features '
               'that lack this property will be given --default_value instead.')
+@options.creation_options
 @click.pass_context
 def rasterize(
         ctx,
@@ -390,7 +398,8 @@ def rasterize(
         all_touched,
         default_value,
         fill,
-        property):
+        property,
+        creation_options):
 
     """Rasterize GeoJSON into a new or existing raster.
 
@@ -439,7 +448,6 @@ def rasterize(
     verbosity = (ctx.obj and ctx.obj.get('verbosity')) or 1
 
     output, files = resolve_inout(files=files, output=output)
-    input = click.open_file(files.pop(0) if files else '-')
 
     has_src_crs = src_crs is not None
     src_crs = src_crs or 'EPSG:4326'
@@ -458,7 +466,8 @@ def rasterize(
                 return feature['properties'].get(property, default_value)
             return default_value
 
-        geojson = json.loads(input.read())
+        with click.open_file(files.pop(0) if files else '-') as gj_f:
+            geojson = json.loads(gj_f.read())
         if 'features' in geojson:
             geometries = []
             for f in geojson['features']:
@@ -545,6 +554,7 @@ def rasterize(
                         raise click.BadParameter(
                             'pixel dimensions are required',
                             ctx, param=res, param_hint='--res')
+
                     elif len(res) == 1:
                         res = (res[0], res[0])
 
@@ -568,6 +578,7 @@ def rasterize(
                                         bounds[3]),
                     'driver': driver
                 }
+                kwargs.update(**creation_options)
 
             result = rasterize(
                 geometries,
@@ -598,19 +609,24 @@ def rasterize(
 @projection_geographic_opt
 @projection_projected_opt
 @projection_mercator_opt
+@click.option(
+    '--dst-crs', default='', metavar="EPSG:NNNN", callback=to_lower,
+    help="Output in specified coordinates.")
 @sequence_opt
 @use_rs_opt
 @geojson_type_collection_opt(True)
 @geojson_type_feature_opt(False)
 @geojson_type_bbox_opt(False)
 @click.pass_context
-def bounds(ctx, input, precision, indent, compact, projection, sequence,
-        use_rs, geojson_type):
+def bounds(ctx, input, precision, indent, compact, projection, dst_crs,
+           sequence, use_rs, geojson_type):
     """Write bounding boxes to stdout as GeoJSON for use with, e.g.,
     geojsonio
 
       $ rio bounds *.tif | geojsonio
-
+    
+    If a destination crs is passed via dst_crs, it takes precedence over
+    the projection parameter.
     """
     import rasterio.warp
     verbosity = (ctx.obj and ctx.obj.get('verbosity')) or 1
@@ -639,12 +655,16 @@ def bounds(ctx, input, precision, indent, compact, projection, sequence,
                     bounds = src.bounds
                     xs = [bounds[0], bounds[2]]
                     ys = [bounds[1], bounds[3]]
-                    if projection == 'geographic':
+                    if dst_crs:
                         xs, ys = rasterio.warp.transform(
-                            src.crs, {'init': 'epsg:4326'}, xs, ys)
-                    if projection == 'mercator':
+                            src.crs, {'init': dst_crs}, xs, ys)
+                    elif projection == 'mercator':
                         xs, ys = rasterio.warp.transform(
                             src.crs, {'init': 'epsg:3857'}, xs, ys)
+                    elif projection == 'geographic':
+                        xs, ys = rasterio.warp.transform(
+                            src.crs, {'init': 'epsg:4326'}, xs, ys)
+
                 if precision >= 0:
                     xs = [round(v, precision) for v in xs]
                     ys = [round(v, precision) for v in ys]
@@ -687,3 +707,4 @@ def bounds(ctx, input, precision, indent, compact, projection, sequence,
 def _disjoint_bounds(bounds1, bounds2):
     return (bounds1[0] > bounds2[2] or bounds1[2] < bounds2[0] or
             bounds1[1] > bounds2[3] or bounds1[3] < bounds2[1])
+
