@@ -20,12 +20,12 @@ from rasterio.transform import Affine
 @options.output_opt
 @format_opt
 @options.bounds_opt
-@click.option('-r', '--res', nargs=2, type=float, default=None,
-              help="Output dataset resolution: pixel width, pixel height")
+@options.resolution_opt
 @click.option('--nodata', type=float, default=None,
               help="Override nodata values defined in input datasets")
+@options.creation_options
 @click.pass_context
-def merge(ctx, files, output, driver, bounds, res, nodata):
+def merge(ctx, files, output, driver, bounds, res, nodata, creation_options):
     """Copy valid pixels from input files to an output file.
 
     All files must have the same number of bands, data type, and
@@ -38,12 +38,19 @@ def merge(ctx, files, output, driver, bounds, res, nodata):
     Geospatial bounds and resolution of a new output file in the
     units of the input file coordinate reference system may be provided
     and are otherwise taken from the first input file.
+
+    Note: --res changed from 2 parameters in 0.25.
+      --res 0.1 0.1  => --res 0.1 (square)
+      --res 0.1 0.2  => --res 0.1 --res 0.2  (rectangular)
     """
     import numpy as np
 
     verbosity = (ctx.obj and ctx.obj.get('verbosity')) or 1
     logger = logging.getLogger('rio')
 
+    if len(res) == 1:
+        res = (res[0], res[0])
+
     try:
         with rasterio.drivers(CPL_DEBUG=verbosity>2):
             output, files = resolve_inout(files=files, output=output)
@@ -51,6 +58,7 @@ def merge(ctx, files, output, driver, bounds, res, nodata):
             with rasterio.open(files[0]) as first:
                 first_res = first.res
                 kwargs = first.meta
+                kwargs.update(**creation_options)
                 kwargs.pop('affine')
                 nodataval = first.nodatavals[0]
                 dtype = first.dtypes[0]
@@ -87,7 +95,7 @@ def merge(ctx, files, output, driver, bounds, res, nodata):
                 output_width = int(math.ceil((bounds[2]-bounds[0])/res[0]))
                 output_height = int(math.ceil((bounds[3]-bounds[1])/res[1]))
 
-                kwargs['driver'] == driver
+                kwargs['driver'] = driver
                 kwargs['transform'] = output_transform
                 kwargs['width'] = output_width
                 kwargs['height'] = output_height
