@@ -2,7 +2,6 @@
 import code
 import collections
 import logging
-import sys
 
 try:
     import matplotlib.pyplot as plt
@@ -49,10 +48,16 @@ def stats(source):
     return Stats(numpy.min(arr), numpy.max(arr), numpy.mean(arr))
 
 
-def main(banner, dataset):
-    """ Main entry point for use with interpreter """
-    code.interact(
-        banner,
-        local=dict(funcs, src=dataset, np=numpy, rio=rasterio, plt=plt))
+def main(banner, dataset, alt_interpreter=None):
+    """ Main entry point for use with python interpreter """
+    local = dict(funcs, src=dataset, np=numpy, rio=rasterio, plt=plt)
+    if not alt_interpreter:
+        code.interact(banner, local=local)
+    elif alt_interpreter == 'ipython':
+        import IPython
+        IPython.InteractiveShell.banner1 = banner
+        IPython.start_ipython(argv=[], user_ns=local)
+    else:
+        raise ValueError("Unsupported interpreter '%s'" % alt_interpreter)
 
     return 0
