@@ -2,13 +2,17 @@ import logging
 import pytest
 import subprocess
 import sys
+import json
 
 import rasterio
 from rasterio import crs
-from rasterio._base import is_geographic_crs, is_projected_crs, is_same_crs
+from rasterio.crs import (
+    is_geographic_crs, is_projected_crs, is_same_crs, is_valid_crs)
+
 
 logging.basicConfig(stream=sys.stderr, level=logging.DEBUG)
 
+
 # When possible, Rasterio gives you the CRS in the form of an EPSG code.
 def test_read_epsg(tmpdir):
     with rasterio.drivers():
@@ -57,6 +61,16 @@ def test_write_3857(tmpdir):
     AUTHORITY["EPSG","3857"]]""" in info.decode('utf-8')
 
 
+def test_from_proj4_json():
+    json_str = '{"proj": "longlat", "ellps": "WGS84", "datum": "WGS84"}'
+    crs_dict = crs.from_string(json_str)
+    assert crs_dict == json.loads(json_str)
+
+    # Test with invalid JSON code
+    with pytest.raises(ValueError):
+        assert crs.from_string('{foo: bar}')
+
+
 def test_from_epsg():
     crs_dict = crs.from_epsg(4326)
     assert crs_dict['init'].lower() == 'epsg:4326'
@@ -66,6 +80,15 @@ def test_from_epsg():
         assert crs.from_epsg(0)
 
 
+def test_from_epsg_string():
+    crs_dict = crs.from_string('epsg:4326')
+    assert crs_dict['init'].lower() == 'epsg:4326'
+
+    # Test with invalid EPSG code
+    with pytest.raises(ValueError):
+        assert crs.from_string('epsg:xyz')
+
+
 def test_bare_parameters():
     """ Make sure that bare parameters (e.g., no_defs) are handled properly,
     even if they come in with key=True.  This covers interaction with pyproj,
@@ -117,4 +140,16 @@ def test_is_same_crs():
     # Make sure that same projection with different parameter are not equal
     lcc_crs1 = crs.from_string('+lon_0=-95 +ellps=GRS80 +y_0=0 +no_defs=True +proj=lcc +x_0=0 +units=m +lat_2=77 +lat_1=49 +lat_0=0')
     lcc_crs2 = crs.from_string('+lon_0=-95 +ellps=GRS80 +y_0=0 +no_defs=True +proj=lcc +x_0=0 +units=m +lat_2=77 +lat_1=45 +lat_0=0')
-    assert is_same_crs(lcc_crs1, lcc_crs2) is False
\ No newline at end of file
+    assert is_same_crs(lcc_crs1, lcc_crs2) is False
+
+
+def test_to_string():
+    assert crs.to_string({'init': 'EPSG:4326'}) == "+init=EPSG:4326"
+
+
+def test_is_valid_false():
+    assert not is_valid_crs('EPSG:432600')
+
+
+def test_is_valid():
+    assert is_valid_crs('EPSG:4326')
