@@ -36,9 +36,16 @@ def test_window():
         left, bottom, right, top = src.bounds
         dx, dy = src.res
         eps = 1.0e-8
-        assert src.window(left+eps, bottom+eps, right-eps, top-eps) == ((0, src.height-1), 
-                                                        (0, src.width-1))
+        assert src.window(
+            left+eps, bottom+eps, right-eps, top-eps) == ((0, src.height),
+                                                          (0, src.width))
         assert src.index(left+400, top-400) == (1, 1)
         assert src.index(left+dx+eps, top-dy-eps) == (1, 1)
         assert src.window(left, top-400, left+400, top) == ((0, 1), (0, 1))
         assert src.window(left, top-2*dy-eps, left+2*dx+eps, top) == ((0, 2), (0, 2))
+
+
+def test_window_bounds_roundtrip():
+    with rasterio.open('tests/data/RGB.byte.tif') as src:
+        assert ((100, 200), (100, 200)) == src.window(
+            *src.window_bounds(((100, 200), (100, 200))))
